==> haskell-safe-exceptions-0.1.7.4-178-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-safe-exceptions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 safe-exceptions
version:              0.1.7.4
visibility:           public
id:                   safe-exceptions-0.1.7.4-HBT1OHFGgS1BzZO408Rgqq
key:                  safe-exceptions-0.1.7.4-HBT1OHFGgS1BzZO408Rgqq
license:              MIT
copyright:            2016 FP Complete
maintainer:           michael@fpcomplete.com
author:               Michael Snoyman
homepage:             https://github.com/fpco/safe-exceptions#readme
synopsis:             Safe, consistent, and easy exception handling
description:          Please see README.md
category:             Control
abi:                  439d69d64f82aec334000a9a669c587d
exposed:              True
exposed-modules:      Control.Exception.Safe
import-dirs:          /usr/lib/ghc-9.4.8/site-local/safe-exceptions-0.1.7.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/safe-exceptions-0.1.7.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/safe-exceptions-0.1.7.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-safe-exceptions
hs-libraries:         HSsafe-exceptions-0.1.7.4-HBT1OHFGgS1BzZO408Rgqq
depends:
    base-4.17.2.1 deepseq-1.4.8.0 exceptions-0.10.5
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-safe-exceptions/html/safe-exceptions.haddock

haddock-html:         /usr/share/doc/haskell-safe-exceptions/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-safe-exceptions-0.1.7.4-180-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-safe-exceptions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 safe-exceptions
version:              0.1.7.4
visibility:           public
id:                   safe-exceptions-0.1.7.4-4UD1DdxenVvLShHqMMN1J8
key:                  safe-exceptions-0.1.7.4-4UD1DdxenVvLShHqMMN1J8
license:              MIT
copyright:            2016 FP Complete
maintainer:           michael@fpcomplete.com
author:               Michael Snoyman
homepage:             https://github.com/fpco/safe-exceptions#readme
synopsis:             Safe, consistent, and easy exception handling
description:          Please see README.md
category:             Control
abi:                  5bfa05a4f66dbe323cd24dc6a1cf271e
exposed:              True
exposed-modules:      Control.Exception.Safe
import-dirs:          /usr/lib/ghc-9.4.8/site-local/safe-exceptions-0.1.7.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/safe-exceptions-0.1.7.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/safe-exceptions-0.1.7.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-safe-exceptions
hs-libraries:         HSsafe-exceptions-0.1.7.4-4UD1DdxenVvLShHqMMN1J8
depends:
    base-4.17.2.1 deepseq-1.4.8.0 exceptions-0.10.5
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-safe-exceptions/html/safe-exceptions.haddock

haddock-html:         /usr/share/doc/haskell-safe-exceptions/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
